aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/llvm/Analysis/DebugInfo.h12
-rw-r--r--lib/Analysis/DebugInfo.cpp14
2 files changed, 14 insertions, 12 deletions
diff --git a/include/llvm/Analysis/DebugInfo.h b/include/llvm/Analysis/DebugInfo.h
index 33986e8026..a6ccc29e79 100644
--- a/include/llvm/Analysis/DebugInfo.h
+++ b/include/llvm/Analysis/DebugInfo.h
@@ -662,13 +662,13 @@ namespace llvm {
Instruction *InsertDeclare(llvm::Value *Storage, DIVariable D,
Instruction *InsertBefore);
- /// InsertValue - Insert a new llvm.dbg.value intrinsic call.
- Instruction *InsertValue(llvm::Value *V, llvm::Value *Offset,
- DIVariable D, BasicBlock *InsertAtEnd);
+ /// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+ Instruction *InsertDbgValueIntrinsic(llvm::Value *V, llvm::Value *Offset,
+ DIVariable D, BasicBlock *InsertAtEnd);
- /// InsertValue - Insert a new llvm.dbg.value intrinsic call.
- Instruction *InsertValue(llvm::Value *V, llvm::Value *Offset,
- DIVariable D, Instruction *InsertBefore);
+ /// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+ Instruction *InsertDbgValueIntrinsic(llvm::Value *V, llvm::Value *Offset,
+ DIVariable D, Instruction *InsertBefore);
private:
Constant *GetTagConstant(unsigned TAG);
};
diff --git a/lib/Analysis/DebugInfo.cpp b/lib/Analysis/DebugInfo.cpp
index 7dc652fb7b..bd81314f46 100644
--- a/lib/Analysis/DebugInfo.cpp
+++ b/lib/Analysis/DebugInfo.cpp
@@ -1078,9 +1078,10 @@ Instruction *DIFactory::InsertDeclare(Value *Storage, DIVariable D,
return CallInst::Create(DeclareFn, Args, Args+2, "", InsertAtEnd);
}
-/// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
- Instruction *InsertBefore) {
+/// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+Instruction *DIFactory::InsertDbgValueIntrinsic(Value *V, Value *Offset,
+ DIVariable D,
+ Instruction *InsertBefore) {
assert(V && "no value passed to dbg.value");
assert(Offset->getType() == Type::getInt64Ty(V->getContext()) &&
"offset must be i64");
@@ -1093,9 +1094,10 @@ Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
return CallInst::Create(ValueFn, Args, Args+3, "", InsertBefore);
}
-/// InsertValue - Insert a new llvm.dbg.value intrinsic call.
-Instruction *DIFactory::InsertValue(Value *V, Value *Offset, DIVariable D,
- BasicBlock *InsertAtEnd) {
+/// InsertDbgValueIntrinsic - Insert a new llvm.dbg.value intrinsic call.
+Instruction *DIFactory::InsertDbgValueIntrinsic(Value *V, Value *Offset,
+ DIVariable D,
+ BasicBlock *InsertAtEnd) {
assert(V && "no value passed to dbg.value");
assert(Offset->getType() == Type::getInt64Ty(V->getContext()) &&
"offset must be i64");